@@ -50,6 +50,7 @@ static GEnumValue _bg_wptype_values[] = {
 	{ WPTYPE_CENTERED, "WPTYPE_CENTERED", "centered"},
 	{ WPTYPE_SCALED, "WPTYPE_SCALED", "scaled"},
 	{ WPTYPE_STRETCHED, "WPTYPE_STRETCHED", "stretched"},
+	{ WPTYPE_ZOOM, "WPTYPE_ZOOM", "zoom"},
 	{ WPTYPE_NONE, "WPTYPE_NONE", "none"},
 	{ 0, NULL, NULL }
 };
@@ -245,12 +246,14 @@ bg_preferences_load (BGPreferences *prefs)
 
 	prefs->enabled = gconf_client_get_bool (client, BG_PREFERENCES_DRAW_BACKGROUND, &error);
 	tmp = gconf_client_get_string (client, BG_PREFERENCES_PICTURE_FILENAME, &error);
-	if (g_utf8_validate (tmp, -1, NULL) &&
-	    g_file_test (tmp, G_FILE_TEST_EXISTS))
-	  prefs->wallpaper_filename = g_strdup (tmp);
-	else
-	  prefs->wallpaper_filename = g_filename_from_utf8 (tmp, -1, NULL,
-							    NULL, NULL);
+	if (tmp) {
+		if (g_utf8_validate (tmp, -1, NULL) &&
+		    g_file_test (tmp, G_FILE_TEST_EXISTS))
+			prefs->wallpaper_filename = g_strdup (tmp);
+		else
+			prefs->wallpaper_filename = g_filename_from_utf8 (tmp, -1, NULL,
+									  NULL, NULL);
+	}
 	g_free (tmp);
 
 	if (prefs->color1 != NULL)
@@ -381,6 +384,8 @@ read_wptype_from_string (gchar *string)
 			type =  WPTYPE_SCALED;
 		} else if (!strncmp (string, "stretched", sizeof ("stretched"))) {
 			type =  WPTYPE_STRETCHED;
+		} else if (!strncmp (string, "zoom", sizeof ("zoom"))) {
+			type =  WPTYPE_ZOOM;
 		}
 		g_free (string);
 	}
@@ -430,6 +435,8 @@ bg_preferences_get_wptype_as_string (wallpaper_type_t wp)
 			return "scaled";
 		case WPTYPE_STRETCHED:
 			return "stretched";
+		case WPTYPE_ZOOM:
+			return "zoom";
 		case WPTYPE_NONE:
 			return "none";
 	        case WPTYPE_UNSET:
