@@ -30,8 +30,10 @@
 #include "nautilus-file-attributes.h"
 #include "nautilus-file-private.h"
 #include "nautilus-file-utilities.h"
+#include "nautilus-search-directory.h"
 #include "nautilus-global-preferences.h"
 #include "nautilus-lib-self-check-functions.h"
+#include "nautilus-marshal.h"
 #include "nautilus-metadata.h"
 #include "nautilus-metafile.h"
 #include "nautilus-desktop-directory.h"
@@ -70,6 +72,8 @@ static void               nautilus_directory_init             (gpointer
 static void               nautilus_directory_class_init (NautilusDirectoryClass *klass);
 static NautilusDirectory *nautilus_directory_new              (const char             *uri);
 static char *             real_get_name_for_self_as_new_file  (NautilusDirectory      *directory);
+static GList *            real_get_file_list                  (NautilusDirectory      *directory);
+static gboolean		  real_is_editable                    (NautilusDirectory      *directory);
 static void               set_directory_uri                   (NautilusDirectory      *directory,
 							       const char             *new_uri);
 
@@ -116,10 +120,14 @@ nautilus_directory_class_init (NautilusDirectoryClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusDirectoryClass, load_error),
 		              NULL, NULL,
-		              g_cclosure_marshal_VOID__INT,
-		              G_TYPE_NONE, 1, G_TYPE_INT);
+		              nautilus_marshal_VOID__INT_STRING,
+		              G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
 
 	klass->get_name_for_self_as_new_file = real_get_name_for_self_as_new_file;
+	klass->get_file_list = real_get_file_list;
+	klass->is_editable = real_is_editable;
+
+	g_type_class_add_private (klass, sizeof (NautilusDirectoryDetails));
 }
 
 static void
@@ -129,25 +137,27 @@ nautilus_directory_init (gpointer object, gpointer klass)
 
 	directory = NAUTILUS_DIRECTORY(object);
 
-	directory->details = g_new0 (NautilusDirectoryDetails, 1);
+	directory->details = G_TYPE_INSTANCE_GET_PRIVATE ((directory), NAUTILUS_TYPE_DIRECTORY, NautilusDirectoryDetails);
 	directory->details->file_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	directory->details->high_priority_queue = nautilus_file_queue_new ();
 	directory->details->low_priority_queue = nautilus_file_queue_new ();
+	directory->details->extension_queue = nautilus_file_queue_new ();
 	directory->details->idle_queue = nautilus_idle_queue_new ();
 
 	directory->details->hidden_file_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 }
 
-void
+NautilusDirectory *
 nautilus_directory_ref (NautilusDirectory *directory)
 {
 	if (directory == NULL) {
-		return;
+		return directory;
 	}
 
-	g_return_if_fail (NAUTILUS_IS_DIRECTORY (directory));
+	g_return_val_if_fail (NAUTILUS_IS_DIRECTORY (directory), NULL);
 
 	g_object_ref (directory);
+	return directory;
 }
 
 void
@@ -207,14 +217,13 @@ nautilus_directory_finalize (GObject *object)
 	
 	nautilus_file_queue_destroy (directory->details->high_priority_queue);
 	nautilus_file_queue_destroy (directory->details->low_priority_queue);
+	nautilus_file_queue_destroy (directory->details->extension_queue);
 	nautilus_idle_queue_destroy (directory->details->idle_queue);
 	g_assert (directory->details->directory_load_in_progress == NULL);
 	g_assert (directory->details->count_in_progress == NULL);
 	g_assert (directory->details->dequeue_pending_idle_id == 0);
 	gnome_vfs_file_info_list_unref (directory->details->pending_file_info);
 
-	g_free (directory->details);
-
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
@@ -302,6 +311,9 @@ add_preferences_callbacks (void)
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS,
 				      async_data_preference_changed_callback,
 				      NULL);
+	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DATE_FORMAT,
+				      async_data_preference_changed_callback,
+				      NULL);
 }
 
 char *
@@ -508,6 +520,10 @@ nautilus_directory_new (const char *uri)
 		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_TRASH_DIRECTORY, NULL));
 	} else if (eel_uri_is_desktop (uri)) {
 		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_DESKTOP_DIRECTORY, NULL));
+	} else if (eel_uri_is_search (uri)) {
+		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_SEARCH_DIRECTORY, NULL));
+	} else if (g_str_has_suffix (uri, NAUTILUS_SAVED_SEARCH_EXTENSION)) {
+		directory = NAUTILUS_DIRECTORY (nautilus_search_directory_new_from_saved_search (uri));
 	} else {
 		directory = NAUTILUS_DIRECTORY (g_object_new (NAUTILUS_TYPE_VFS_DIRECTORY, NULL));
 	}
@@ -757,11 +773,12 @@ nautilus_directory_emit_done_loading (NautilusDirectory *directory)
 
 void
 nautilus_directory_emit_load_error (NautilusDirectory *directory,
-				    GnomeVFSResult error_result)
+				    GnomeVFSResult error_result,
+				    const char *error_message)
 {
 	g_signal_emit (directory,
 			 signals[LOAD_ERROR], 0,
-			 error_result);
+			 error_result, error_message);
 }
 
 
@@ -987,7 +1004,6 @@ nautilus_directory_notify_files_added (GList *uris)
 		nautilus_directory_unref (directory);
 	}
 
-
 	/* Now get file info for the new files. This creates NautilusFile
 	 * objects for the new files, and sends out a files_added signal. 
 	 */
@@ -1023,6 +1039,7 @@ nautilus_directory_notify_files_changed (GList *uris)
 			file->details->file_info_is_up_to_date = FALSE;
 			file->details->top_left_text_is_up_to_date = FALSE;
 			file->details->link_info_is_up_to_date = FALSE;
+			nautilus_file_invalidate_extension_info_internal (file);
 
 			hash_table_list_prepend (changed_lists,
 						 file->details->directory,
@@ -1069,8 +1086,9 @@ nautilus_directory_notify_files_removed (GList *uris)
 			nautilus_file_mark_gone (file);
 			hash_table_list_prepend (changed_lists,
 						 file->details->directory,
-						 file);
+						 nautilus_file_ref (file));
 		}
+		nautilus_file_unref (file);
 	}
 
 	/* Now send out the changed signals. */
@@ -1372,11 +1390,13 @@ nautilus_directory_schedule_metadata_copy (GList *uri_pairs)
 		
 		source_relative_uri = g_path_get_basename (pair->from_uri);
 		destination_relative_uri = g_path_get_basename (pair->to_uri);
-		
-		nautilus_directory_copy_file_metadata (source_directory,
-						       source_relative_uri,
-						       destination_directory,
-						       destination_relative_uri);
+
+		if (source_directory != NULL && destination_directory != NULL) {
+			nautilus_directory_copy_file_metadata (source_directory,
+							       source_relative_uri,
+							       destination_directory,
+							       destination_relative_uri);
+		}
 
 		g_free (source_relative_uri);
 		g_free (destination_relative_uri);
@@ -1468,7 +1488,11 @@ nautilus_directory_schedule_position_set (GList *position_setting_list)
 			 position_string);
 		g_free (position_string);
 
-		screen_string = g_strdup_printf ("%d", item->screen);
+		if (item->set) {
+			screen_string = g_strdup_printf ("%d", item->screen);
+		} else {
+			screen_string = NULL;
+		}
 		nautilus_file_set_metadata
 			(file,
 			 NAUTILUS_METADATA_KEY_SCREEN,
@@ -1618,6 +1642,14 @@ is_tentative (gpointer data, gpointer callback_data)
 
 GList *
 nautilus_directory_get_file_list (NautilusDirectory *directory)
+{
+	return EEL_CALL_METHOD_WITH_RETURN_VALUE
+		(NAUTILUS_DIRECTORY_CLASS, directory,
+		 get_file_list, (directory));
+}
+
+static GList *
+real_get_file_list (NautilusDirectory *directory)
 {
 	GList *tentative_files, *non_tentative_files;
 
@@ -1630,6 +1662,20 @@ nautilus_directory_get_file_list (NautilusDirectory *directory)
 	return non_tentative_files;
 }
 
+static gboolean
+real_is_editable (NautilusDirectory *directory)
+{
+	return TRUE;
+}
+
+gboolean
+nautilus_directory_is_editable (NautilusDirectory *directory)
+{
+	return EEL_CALL_METHOD_WITH_RETURN_VALUE
+		(NAUTILUS_DIRECTORY_CLASS, directory, 
+		 is_editable, (directory));
+}
+
 GList *
 nautilus_directory_match_pattern (NautilusDirectory *directory, const char *pattern)
 {
