@@ -50,7 +50,7 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkiconfactory.h>
 #include <gtk/gtkicontheme.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-macros.h>
 #include <libgnomeui/gnome-icon-lookup.h>
@@ -1106,7 +1106,7 @@ path_represents_svg_image (const char *path)
 	 * and if they're doing that, they can behave themselves
 	 * and use a .svg extension.
 	 */
-	return path != NULL && (strstr (path, ".svg") != NULL || strstr (path, ".svgz") != NULL);
+	return path != NULL && (g_str_has_suffix (path, ".svg") || g_str_has_suffix (path, ".svgz"));
 }
 
 static GdkPixbuf *
@@ -1127,7 +1127,10 @@ scale_icon (GdkPixbuf *pixbuf,
 	width = floor (width * *scale + 0.5);
 	height = floor (height * *scale + 0.5);
 	
-	return gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
+	return gdk_pixbuf_scale_simple (pixbuf,
+					width == 0 ? 1 : width,
+					height == 0 ? 1 : height,
+					GDK_INTERP_BILINEAR);
 }
 
 static GdkPixbuf *
