@@ -27,7 +27,7 @@
 #include <gtk/gtkvbox.h>
 #include <gtk/gtklabel.h>
 #include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <eel/eel-gnome-extensions.h>
 #include <libnautilus-extension/nautilus-property-page-provider.h>
@@ -144,13 +144,20 @@ static void
 exif_content_callback (ExifContent *content, gpointer data)
 {
 	struct ExifAttribute *attribute;
+#if !HAVE_OLD_EXIF
+	char b[1024];
+#endif
 
 	attribute = (struct ExifAttribute *)data;
 	if (attribute->found) {
 		return;
 	}
 
+#ifdef HAVE_OLD_EXIF
         attribute->value = g_strdup (exif_content_get_value (content, attribute->tag));
+#else
+        attribute->value = g_strdup (exif_content_get_value (content, attribute->tag, b, sizeof(b)));
+#endif
 	if (attribute->value != NULL) {
 		attribute->found = TRUE;
 	}
@@ -239,10 +246,16 @@ load_finished (NautilusImagePropertiesPage *page)
 	
 		name = gdk_pixbuf_format_get_name (format);
 		desc = gdk_pixbuf_format_get_description (format);
-		g_string_append_printf (str, ngettext ("<b>Image Type:</b> %s (%s)\n<b>Resolution:</b> %dx%d pixels\n",
-						       "<b>Image Type:</b> %s (%s)\n<b>Resolution:</b> %dx%d pixels\n",
+		g_string_append_printf (str, _("<b>Image Type:</b> %s (%s)\n"),
+					name, desc);
+		g_string_append_printf (str, ngettext ("<b>Width:</b> %d pixel\n",
+						       "<b>Width:</b> %d pixels\n",
+						       page->details->width),
+					page->details->width);
+		g_string_append_printf (str, ngettext ("<b>Height:</b> %d pixel\n",
+						       "<b>Height:</b> %d pixels\n",
 						       page->details->height),
-					name, desc, page->details->width, page->details->height);
+					page->details->height);
 		g_free (name);
 		g_free (desc);
 		
