@@ -42,7 +42,7 @@
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtksignal.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -291,7 +291,7 @@ try_to_expand_path (gpointer callback_data)
 			pos = user_location_length;
 			gtk_editable_insert_text (editable,
 						  insert_text,
-						  g_utf8_strlen (insert_text, -1),
+						  strlen (insert_text),
 						  &pos);
 
 			pos = user_location_length;
